@@ -38,6 +38,8 @@ pub mod janus_auth_request;
 pub use self::janus_auth_request::JanusAuthRequest;
 pub mod janus_cloud_stream;
 pub use self::janus_cloud_stream::JanusCloudStream;
+pub mod janus_cloud_stream_request;
+pub use self::janus_cloud_stream_request::JanusCloudStreamRequest;
 pub mod janus_config_type;
 pub use self::janus_config_type::JanusConfigType;
 pub mod janus_edge_stream;
@@ -46,6 +48,8 @@ pub mod janus_edge_stream_request;
 pub use self::janus_edge_stream_request::JanusEdgeStreamRequest;
 pub mod janus_stream;
 pub use self::janus_stream::JanusStream;
+pub mod janus_stream_request;
+pub use self::janus_stream_request::JanusStreamRequest;
 pub mod mobile_auth_request;
 pub use self::mobile_auth_request::MobileAuthRequest;
 pub mod octo_print_backup;
@@ -96,6 +100,8 @@ pub mod patched_cloudiot_device_request;
 pub use self::patched_cloudiot_device_request::PatchedCloudiotDeviceRequest;
 pub mod patched_device_request;
 pub use self::patched_device_request::PatchedDeviceRequest;
+pub mod patched_janus_cloud_stream_request;
+pub use self::patched_janus_cloud_stream_request::PatchedJanusCloudStreamRequest;
 pub mod patched_janus_edge_stream_request;
 pub use self::patched_janus_edge_stream_request::PatchedJanusEdgeStreamRequest;
 pub mod patched_octo_print_settings_request;
